@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2017-09-08'; # DATE
-our $VERSION = '0.260'; # VERSION
+our $DATE = '2021-02-02'; # DATE
+our $VERSION = '0.261'; # VERSION
 
 use 5.010001;
 use strict;
@@ -56,6 +56,70 @@ if ($ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES}) {
     };
 }
 
+our %args_module_common = (
+    %arg_word,
+    path_sep => {
+        summary => 'Path separator',
+        schema  => 'str*',
+        description => <<'_',
+
+For convenience in shell (bash) completion, instead of defaulting to `::` all
+the time, will look at `word`. If word does not contain any `::` then will
+default to `/`. This is because `::` (contains colon) is rather problematic as
+it is by default a word-break character in bash and the word needs to be quoted
+to avoid word-breaking by bash.
+
+_
+    },
+    find_pm => {
+        summary => 'Whether to find .pm files',
+        schema  => 'bool*',
+        default => 1,
+    },
+    find_pod => {
+        summary => 'Whether to find .pod files',
+        schema  => 'bool*',
+        default => 1,
+    },
+    find_pmc => {
+        summary => 'Whether to find .pmc files',
+        schema  => 'bool*',
+        default => 1,
+    },
+    find_prefix => {
+        summary => 'Whether to find module prefixes',
+        schema  => 'bool*',
+        default => 1,
+    },
+    ns_prefix => {
+        summary => 'Namespace prefix',
+        schema  => 'str*',
+        description => <<'_',
+
+This is useful if you want to complete module under a specific namespace
+(instead of the root). For example, if you set `ns_prefix` to
+`Dist::Zilla::Plugin` (or `Dist::Zilla::Plugin::`) and word is `F`, you can get
+`['FakeRelease', 'FileFinder::', 'FinderCode']` (those are modules under the
+`Dist::Zilla::Plugin::` namespace).
+
+_
+    },
+    recurse => {
+        schema => 'bool*',
+        cmdline_aliases => {r=>{}},
+    },
+    recurse_matching => {
+        schema => ['str*', in=>['level-by-level', 'all-at-once']],
+        default => 'level-by-level',
+    },
+    exclude_leaf => {
+        schema => 'bool*',
+    },
+    exclude_dir => {
+        schema => 'bool*',
+    },
+);
+
 $SPEC{complete_module} = {
     v => 1.1,
     summary => 'Complete with installed Perl module names',
@@ -76,53 +140,7 @@ character, some shortcuts, and so on.
 
 _
     args => {
-        %arg_word,
-        path_sep => {
-            summary => 'Path separator',
-            schema  => 'str*',
-            description => <<'_',
-
-For convenience in shell (bash) completion, instead of defaulting to `::` all
-the time, will look at `word`. If word does not contain any `::` then will
-default to `/`. This is because `::` (contains colon) is rather problematic as
-it is by default a word-break character in bash and the word needs to be quoted
-to avoid word-breaking by bash.
-
-_
-        },
-        find_pm => {
-            summary => 'Whether to find .pm files',
-            schema  => 'bool*',
-            default => 1,
-        },
-        find_pod => {
-            summary => 'Whether to find .pod files',
-            schema  => 'bool*',
-            default => 1,
-        },
-        find_pmc => {
-            summary => 'Whether to find .pmc files',
-            schema  => 'bool*',
-            default => 1,
-        },
-        find_prefix => {
-            summary => 'Whether to find module prefixes',
-            schema  => 'bool*',
-            default => 1,
-        },
-        ns_prefix => {
-            summary => 'Namespace prefix',
-            schema  => 'str*',
-            description => <<'_',
-
-This is useful if you want to complete module under a specific namespace
-(instead of the root). For example, if you set `ns_prefix` to
-`Dist::Zilla::Plugin` (or `Dist::Zilla::Plugin::`) and word is `F`, you can get
-`['FakeRelease', 'FileFinder::', 'FinderCode']` (those are modules under the
-`Dist::Zilla::Plugin::` namespace).
-
-_
-        },
+        %args_module_common,
     },
     result_naked => 1,
 };
@@ -198,6 +216,10 @@ sub complete_module {
         },
         path_sep => '::',
         is_dir_func => sub { }, # not needed, we already suffix "dirs" with ::
+        recurse => $args{recurse},
+        recurse_matching => $args{recurse_matching},
+        exclude_leaf => $args{exclude_leaf},
+        exclude_dir  => $args{exclude_dir},
     );
 
     for (@$res) { s/::/$sep/g }
@@ -222,7 +244,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.260 of Complete::Module (from Perl distribution Complete-Module), released on 2017-09-08.
+This document describes version 0.261 of Complete::Module (from Perl distribution Complete-Module), released on 2021-02-02.
 
 =head1 SYNOPSIS
 
@@ -285,6 +307,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<exclude_dir> => I<bool>
+
+=item * B<exclude_leaf> => I<bool>
+
 =item * B<find_pm> => I<bool> (default: 1)
 
 Whether to find .pm files.
@@ -321,10 +347,15 @@ default to C</>. This is because C<::> (contains colon) is rather problematic as
 it is by default a word-break character in bash and the word needs to be quoted
 to avoid word-breaking by bash.
 
+=item * B<recurse> => I<bool>
+
+=item * B<recurse_matching> => I<str> (default: "level-by-level")
+
 =item * B<word>* => I<str> (default: "")
 
 Word to complete.
 
+
 =back
 
 Return value:  (any)
@@ -352,7 +383,7 @@ Source repository is at L<https://github.com/perlancar/perl-Complete-Module>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Module>
+Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Complete-Module/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -368,7 +399,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2017, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
